@@ -40,8 +40,8 @@ func TestGetBranch(t *testing.T) {
 	assert.NoError(t, err)
 	assert.NotNil(t, resp)
 
-	authoredDate := time.Date(2012, 6, 27, 5, 51, 39, 0, time.UTC)
-	committedDate := time.Date(2012, 6, 28, 3, 44, 20, 0, time.UTC)
+	authoredDate := time.Date(2012, time.June, 27, 5, 51, 39, 0, time.UTC)
+	committedDate := time.Date(2012, time.June, 28, 3, 44, 20, 0, time.UTC)
 	want := &Branch{
 		Name:               DefaultBranch,
 		Merged:             false,
@@ -77,8 +77,8 @@ func TestBranchesService_ListBranches(t *testing.T) {
 		mustWriteHTTPResponse(t, w, "testdata/list_branches.json")
 	})
 
-	authoredDate := time.Date(2012, 6, 27, 5, 51, 39, 0, time.UTC)
-	committedDate := time.Date(2012, 6, 28, 3, 44, 20, 0, time.UTC)
+	authoredDate := time.Date(2012, time.June, 27, 5, 51, 39, 0, time.UTC)
+	committedDate := time.Date(2012, time.June, 28, 3, 44, 20, 0, time.UTC)
 	want := []*Branch{
 		{
 			Name:               DefaultBranch,
@@ -139,7 +139,7 @@ func TestBranchesService_ListBranches(t *testing.T) {
 	assert.Nil(t, b)
 
 	b, resp, err = client.Branches.ListBranches(5, nil, errorOption)
-	assert.EqualError(t, err, "RequestOptionFunc returns an error")
+	assert.ErrorIs(t, err, errRequestOptionFunc)
 	assert.Nil(t, resp)
 	assert.Nil(t, b)
 
@@ -169,8 +169,8 @@ func TestBranchesService_ListBranchesWithSearch(t *testing.T) {
 	require.NotNil(t, b)
 	assert.Equal(t, http.StatusOK, resp.StatusCode)
 
-	authoredDate := time.Date(2012, 6, 27, 5, 51, 39, 0, time.UTC)
-	committedDate := time.Date(2012, 6, 28, 3, 44, 20, 0, time.UTC)
+	authoredDate := time.Date(2012, time.June, 27, 5, 51, 39, 0, time.UTC)
+	committedDate := time.Date(2012, time.June, 28, 3, 44, 20, 0, time.UTC)
 	expectedBranches := []*Branch{
 		{
 			Name:               DefaultBranch,
@@ -242,8 +242,8 @@ func TestBranchesService_ListBranchesWithRegex(t *testing.T) {
 	require.NotNil(t, b)
 	assert.Equal(t, http.StatusOK, resp.StatusCode)
 
-	authoredDate := time.Date(2012, 6, 27, 5, 51, 39, 0, time.UTC)
-	committedDate := time.Date(2012, 6, 28, 3, 44, 20, 0, time.UTC)
+	authoredDate := time.Date(2012, time.June, 27, 5, 51, 39, 0, time.UTC)
+	committedDate := time.Date(2012, time.June, 28, 3, 44, 20, 0, time.UTC)
 	expectedBranch := []*Branch{
 		{
 			Name:               DefaultBranch,
@@ -304,8 +304,8 @@ func TestBranchesService_CreateBranch(t *testing.T) {
 		mustWriteHTTPResponse(t, w, "testdata/get_branch.json")
 	})
 
-	authoredDate := time.Date(2012, 6, 27, 5, 51, 39, 0, time.UTC)
-	committedDate := time.Date(2012, 6, 28, 3, 44, 20, 0, time.UTC)
+	authoredDate := time.Date(2012, time.June, 27, 5, 51, 39, 0, time.UTC)
+	committedDate := time.Date(2012, time.June, 28, 3, 44, 20, 0, time.UTC)
 	want := &Branch{
 		Name:               "master",
 		Merged:             false,
@@ -340,7 +340,7 @@ func TestBranchesService_CreateBranch(t *testing.T) {
 	assert.Nil(t, b)
 
 	b, resp, err = client.Branches.CreateBranch(1, nil, errorOption)
-	assert.EqualError(t, err, "RequestOptionFunc returns an error")
+	assert.ErrorIs(t, err, errRequestOptionFunc)
 	assert.Nil(t, resp)
 	assert.Nil(t, b)
 
@@ -367,7 +367,7 @@ func TestBranchesService_DeleteBranch(t *testing.T) {
 	assert.Nil(t, resp)
 
 	resp, err = client.Branches.DeleteBranch(1, "master", nil, errorOption)
-	assert.EqualError(t, err, "RequestOptionFunc returns an error")
+	assert.ErrorIs(t, err, errRequestOptionFunc)
 	assert.Nil(t, resp)
 
 	resp, err = client.Branches.DeleteBranch(3, "master", nil)
@@ -392,7 +392,7 @@ func TestBranchesService_DeleteMergedBranches(t *testing.T) {
 	assert.Nil(t, resp)
 
 	resp, err = client.Branches.DeleteMergedBranches(1, nil, errorOption)
-	assert.EqualError(t, err, "RequestOptionFunc returns an error")
+	assert.ErrorIs(t, err, errRequestOptionFunc)
 	assert.Nil(t, resp)
 
 	resp, err = client.Branches.DeleteMergedBranches(3, nil)
