@@ -46,8 +46,8 @@ func TestGetCommit(t *testing.T) {
 		t.Fatalf("Commits.GetCommit returned error: %v, response: %v", err, resp)
 	}
 
-	updatedAt := time.Date(2019, 11, 4, 15, 39, 0o3, 935000000, time.UTC)
-	createdAt := time.Date(2019, 11, 4, 15, 38, 53, 154000000, time.UTC)
+	updatedAt := time.Date(2019, time.November, 4, 15, 39, 3, 935000000, time.UTC)
+	createdAt := time.Date(2019, time.November, 4, 15, 38, 53, 154000000, time.UTC)
 	want := &Commit{
 		ID:             "6104942438c14ec7bd21c6cd5bd995272b3faff6",
 		ShortID:        "6104942438c",
@@ -185,8 +185,8 @@ func TestRevertCommit_NoOptions(t *testing.T) {
 		t.Fatalf("Commits.RevertCommit returned error: %v, response: %v", err, resp)
 	}
 
-	updatedAt := time.Date(2019, 11, 4, 15, 39, 0o3, 935000000, time.UTC)
-	createdAt := time.Date(2019, 11, 4, 15, 38, 53, 154000000, time.UTC)
+	updatedAt := time.Date(2019, time.November, 4, 15, 39, 3, 935000000, time.UTC)
+	createdAt := time.Date(2019, time.November, 4, 15, 38, 53, 154000000, time.UTC)
 	want := &Commit{
 		ID:             "6104942438c14ec7bd21c6cd5bd995272b3faff6",
 		ShortID:        "6104942438c",
@@ -233,8 +233,8 @@ func TestRevertCommit_WithOptions(t *testing.T) {
 		t.Fatalf("Commits.RevertCommit returned error: %v, response: %v", err, resp)
 	}
 
-	updatedAt := time.Date(2019, 11, 4, 15, 39, 0o3, 935000000, time.UTC)
-	createdAt := time.Date(2019, 11, 4, 15, 38, 53, 154000000, time.UTC)
+	updatedAt := time.Date(2019, time.November, 4, 15, 39, 3, 935000000, time.UTC)
+	createdAt := time.Date(2019, time.November, 4, 15, 38, 53, 154000000, time.UTC)
 	want := &Commit{
 		ID:             "6104942438c14ec7bd21c6cd5bd995272b3faff6",
 		ShortID:        "6104942438c",
@@ -329,8 +329,8 @@ func TestCommitsService_ListCommits(t *testing.T) {
 		`)
 	})
 
-	updatedAt := time.Date(2019, 11, 4, 15, 39, 0o3, 935000000, time.UTC)
-	createdAt := time.Date(2019, 11, 4, 15, 38, 53, 154000000, time.UTC)
+	updatedAt := time.Date(2019, time.November, 4, 15, 39, 3, 935000000, time.UTC)
+	createdAt := time.Date(2019, time.November, 4, 15, 38, 53, 154000000, time.UTC)
 	want := []*Commit{{
 		ID:             "6104942438c14ec7bd21c6cd5bd995272b3faff6",
 		ShortID:        "6104942438c",
@@ -366,7 +366,7 @@ func TestCommitsService_ListCommits(t *testing.T) {
 	require.Nil(t, cs)
 
 	cs, resp, err = client.Commits.ListCommits(1, nil, errorOption)
-	require.EqualError(t, err, "RequestOptionFunc returns an error")
+	require.ErrorIs(t, err, errRequestOptionFunc)
 	require.Nil(t, resp)
 	require.Nil(t, cs)
 
@@ -422,7 +422,7 @@ func TestCommitsService_GetCommitRefs(t *testing.T) {
 	require.Nil(t, crs)
 
 	crs, resp, err = client.Commits.GetCommitRefs(1, "5937ac0a7beb003549fc5fd26fc247adbce4a52e", nil, errorOption)
-	require.EqualError(t, err, "RequestOptionFunc returns an error")
+	require.ErrorIs(t, err, errRequestOptionFunc)
 	require.Nil(t, resp)
 	require.Nil(t, crs)
 
@@ -471,8 +471,8 @@ func TestCommitsService_CreateCommit(t *testing.T) {
 		`)
 	})
 
-	updatedAt := time.Date(2019, 11, 4, 15, 39, 0o3, 935000000, time.UTC)
-	createdAt := time.Date(2019, 11, 4, 15, 38, 53, 154000000, time.UTC)
+	updatedAt := time.Date(2019, time.November, 4, 15, 39, 3, 935000000, time.UTC)
+	createdAt := time.Date(2019, time.November, 4, 15, 38, 53, 154000000, time.UTC)
 	want := &Commit{
 		ID:             "6104942438c14ec7bd21c6cd5bd995272b3faff6",
 		ShortID:        "6104942438c",
@@ -508,7 +508,7 @@ func TestCommitsService_CreateCommit(t *testing.T) {
 	require.Nil(t, c)
 
 	c, resp, err = client.Commits.CreateCommit(1, nil, errorOption)
-	require.EqualError(t, err, "RequestOptionFunc returns an error")
+	require.ErrorIs(t, err, errRequestOptionFunc)
 	require.Nil(t, resp)
 	require.Nil(t, c)
 
@@ -558,7 +558,7 @@ func TestCommitsService_GetCommitDiff(t *testing.T) {
 	require.Nil(t, ds)
 
 	ds, resp, err = client.Commits.GetCommitDiff(1, DefaultBranch, nil, errorOption)
-	require.EqualError(t, err, "RequestOptionFunc returns an error")
+	require.ErrorIs(t, err, errRequestOptionFunc)
 	require.Nil(t, resp)
 	require.Nil(t, ds)
 
@@ -612,7 +612,7 @@ func TestCommitsService_GetCommitComments(t *testing.T) {
 	require.Nil(t, ccs)
 
 	ccs, resp, err = client.Commits.GetCommitComments(1, DefaultBranch, nil, errorOption)
-	require.EqualError(t, err, "RequestOptionFunc returns an error")
+	require.ErrorIs(t, err, errRequestOptionFunc)
 	require.Nil(t, resp)
 	require.Nil(t, ccs)
 
@@ -664,7 +664,7 @@ func TestCommitsService_PostCommitComment(t *testing.T) {
 	require.Nil(t, cc)
 
 	cc, resp, err = client.Commits.PostCommitComment(1, DefaultBranch, nil, errorOption)
-	require.EqualError(t, err, "RequestOptionFunc returns an error")
+	require.ErrorIs(t, err, errRequestOptionFunc)
 	require.Nil(t, resp)
 	require.Nil(t, cc)
 
@@ -871,7 +871,7 @@ func TestCommitsService_ListMergeRequestsByCommit(t *testing.T) {
 	require.Nil(t, mrs)
 
 	mrs, resp, err = client.Commits.ListMergeRequestsByCommit(1, DefaultBranch, nil, errorOption)
-	require.EqualError(t, err, "RequestOptionFunc returns an error")
+	require.ErrorIs(t, err, errRequestOptionFunc)
 	require.Nil(t, resp)
 	require.Nil(t, mrs)
 
@@ -920,8 +920,8 @@ func TestCommitsService_CherryPickCommit(t *testing.T) {
 		`)
 	})
 
-	updatedAt := time.Date(2019, 11, 4, 15, 39, 0o3, 935000000, time.UTC)
-	createdAt := time.Date(2019, 11, 4, 15, 38, 53, 154000000, time.UTC)
+	updatedAt := time.Date(2019, time.November, 4, 15, 39, 3, 935000000, time.UTC)
+	createdAt := time.Date(2019, time.November, 4, 15, 38, 53, 154000000, time.UTC)
 	want := &Commit{
 		ID:             "6104942438c14ec7bd21c6cd5bd995272b3faff6",
 		ShortID:        "6104942438c",
@@ -957,7 +957,7 @@ func TestCommitsService_CherryPickCommit(t *testing.T) {
 	require.Nil(t, c)
 
 	c, resp, err = client.Commits.CherryPickCommit(1, DefaultBranch, nil, errorOption)
-	require.EqualError(t, err, "RequestOptionFunc returns an error")
+	require.ErrorIs(t, err, errRequestOptionFunc)
 	require.Nil(t, resp)
 	require.Nil(t, c)
 
