@@ -28,7 +28,7 @@ import (
 	"buf.build/go/protoyaml"
 	"github.com/zalando/go-keyring"
 	gitlab "gitlab.com/gitlab-org/api/client-go"
-	v1beta1 "gitlab.com/gitlab-org/api/client-go/config/v1beta1"
+	"gitlab.com/gitlab-org/api/client-go/config/v1beta1"
 	"gitlab.com/gitlab-org/api/client-go/gitlaboauth2"
 	"golang.org/x/oauth2"
 	"golang.org/x/time/rate"
@@ -498,9 +498,22 @@ func (c *Config) NewClientForContext(name string, options ...gitlab.ClientOption
 		return nil, err
 	}
 
+	defaultRequestOptions := []gitlab.RequestOptionFunc{
+		gitlab.WithContext(c.ctx),
+	}
+
+	// custom headers
+	customHeaders, err := c.resolveCustomHeaders(instance.CustomHeaders)
+	if err != nil {
+		return nil, err
+	}
+	if len(customHeaders) > 0 {
+		defaultRequestOptions = append(defaultRequestOptions, gitlab.WithHeaders(customHeaders))
+	}
+
 	configOptions := []gitlab.ClientOptionFunc{
 		gitlab.WithBaseURL(baseURL.String()),
-		gitlab.WithRequestOptions(gitlab.WithContext(c.ctx)),
+		gitlab.WithRequestOptions(defaultRequestOptions...),
 	}
 
 	if c.config.Preferences.RetryMax != nil {
@@ -842,6 +855,27 @@ func (c *Config) resolveOAuth2ClientSecret(o *v1beta1.OAuth2) (string, error) {
 	}
 }
 
+func (c *Config) resolveCustomHeaders(headers []*v1beta1.Header) (map[string]string, error) {
+	hs := make(map[string]string, len(headers))
+
+	for _, header := range headers {
+		switch v := header.HeaderValue.(type) {
+		case *v1beta1.Header_Value:
+			hs[*header.Name] = v.Value
+		case *v1beta1.Header_ValueFrom:
+			csv, err := c.resolveCredentialSource(v.ValueFrom)
+			if err != nil {
+				return nil, err
+			}
+			hs[*header.Name] = csv
+		default:
+			panic(fmt.Sprintf("unexpected v1beta.HeaderValue type: %#v. Please report at https://gitlab.com/gitlab-org/api/client-go/-/issues", v))
+		}
+	}
+
+	return hs, nil
+}
+
 func (c *Config) resolveCredentialSource(cs *v1beta1.CredentialSource) (string, error) {
 	switch s := cs.Source.(type) {
 	case *v1beta1.CredentialSource_EnvVar:
