@@ -23,6 +23,7 @@ import (
 	"fmt"
 	"io"
 	"net/http"
+	"net/http/cookiejar"
 	"net/http/httptest"
 	"net/url"
 	"os"
@@ -40,6 +41,14 @@ import (
 
 var timeLayout = "2006-01-02T15:04:05Z07:00"
 
+// Interface implementation checks.
+var (
+	_ AuthSource = OAuthTokenSource{}
+	_ AuthSource = JobTokenAuthSource{}
+	_ AuthSource = AccessTokenAuthSource{}
+	_ AuthSource = (*PasswordCredentialsAuthSource)(nil)
+)
+
 // setup sets up a test HTTP server along with a gitlab.Client that is
 // configured to talk to that test server.  Tests should register handlers on
 // mux which provide mock responses for the API method being tested.
@@ -110,7 +119,7 @@ func testBodyJSON[T any](t *testing.T, r *http.Request, want T) bool {
 // testParam checks whether the given request contains the expected parameter and whether the parameter has the expected value.
 func testParam(t *testing.T, r *http.Request, key, value string) {
 	require.True(t, r.URL.Query().Has(key), "Request does not contain the %q parameter", key)
-	assert.Equal(t, 1, len(r.URL.Query()[key]), "Request contains multiple %q parameters when only one is expected", key)
+	assert.Len(t, r.URL.Query()[key], 1, "Request contains multiple %q parameters when only one is expected", key)
 	require.Equal(t, value, r.URL.Query().Get(key))
 }
 
@@ -144,8 +153,10 @@ func mustWriteErrorResponse(t *testing.T, w io.Writer, err error) {
 	})
 }
 
+var errRequestOptionFunc = errors.New("RequestOptionFunc returns an error")
+
 func errorOption(*retryablehttp.Request) error {
-	return errors.New("RequestOptionFunc returns an error")
+	return errRequestOptionFunc
 }
 
 func TestNewClient(t *testing.T) {
@@ -835,10 +846,293 @@ func TestNewAuthSourceClient(t *testing.T) {
 	assert.Equal(t, []*Project{}, projects)
 }
 
-// Interface implementation checks.
-var (
-	_ AuthSource = OAuthTokenSource{}
-	_ AuthSource = JobTokenAuthSource{}
-	_ AuthSource = AccessTokenAuthSource{}
-	_ AuthSource = (*PasswordCredentialsAuthSource)(nil)
-)
+func TestHasStatusCode(t *testing.T) {
+	// GIVEN
+	tests := []struct {
+		name          string
+		err           error
+		hasStatusCode int
+		expect        bool
+	}{
+		{
+			name:          "error is nil",
+			err:           nil,
+			hasStatusCode: http.StatusOK,
+			expect:        false,
+		},
+		{
+			name:          "error is not a ErrorResponse",
+			err:           errors.New("dummy"),
+			hasStatusCode: http.StatusOK,
+			expect:        false,
+		},
+		{
+			name:          "error is a ErrorResponse, but has no http.Response",
+			err:           &ErrorResponse{},
+			hasStatusCode: http.StatusOK,
+			expect:        false,
+		},
+		{
+			name:          "error has different status code",
+			err:           &ErrorResponse{Response: &http.Response{StatusCode: http.StatusBadRequest}},
+			hasStatusCode: http.StatusOK,
+			expect:        false,
+		},
+		{
+			name:          "error has expected status code",
+			err:           &ErrorResponse{Response: &http.Response{StatusCode: http.StatusOK}},
+			hasStatusCode: http.StatusOK,
+			expect:        true,
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			// WHEN
+			actual := HasStatusCode(tt.err, tt.hasStatusCode)
+
+			// THEN
+			assert.Equal(t, tt.expect, actual)
+		})
+	}
+}
+
+func TestNewRequestToURL_disallowedURL(t *testing.T) {
+	// GIVEN
+	tests := []struct {
+		name string
+		url  string
+	}{
+		{
+			name: "wrong scheme",
+			url:  "http://gitlab.example.com",
+		},
+		{
+			name: "wrong hostname",
+			url:  "https://gitlab2.example.com",
+		},
+		{
+			name: "wrong port",
+			url:  "https://gitlab.example.com:8080",
+		},
+	}
+	c, err := NewClient("",
+		WithBaseURL("https://gitlab.example.com"),
+	)
+	require.NoError(t, err)
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			u, err := url.Parse(tt.url)
+			require.NoError(t, err)
+
+			// WHEN
+			_, err = c.NewRequestToURL(http.MethodGet, u, nil, nil)
+			assert.Error(t, err)
+		})
+	}
+}
+
+func TestNewRequestToURL_allowedURL(t *testing.T) {
+	// GIVEN
+	tests := []struct {
+		url string
+	}{
+		{
+			url: "https://gitlab.example.com",
+		},
+		{
+			url: "https://gitlab.example.com/api/v4",
+		},
+	}
+	c, err := NewClient("",
+		WithBaseURL("https://gitlab.example.com"),
+	)
+	require.NoError(t, err)
+
+	for _, tt := range tests {
+		t.Run(tt.url, func(t *testing.T) {
+			u, err := url.Parse(tt.url)
+			require.NoError(t, err)
+
+			// WHEN
+			_, err = c.NewRequestToURL(http.MethodGet, u, nil, nil)
+			assert.NoError(t, err)
+		})
+	}
+}
+
+func TestClient_CookieJar(t *testing.T) {
+	t.Parallel()
+
+	mux := http.NewServeMux()
+	mux.HandleFunc("/api/v4/user", func(w http.ResponseWriter, r *http.Request) {
+		cookie, err := r.Cookie("test-cookie")
+		require.NoError(t, err)
+
+		assert.Equal(t, "yummy", cookie.Value)
+
+		http.SetCookie(w, &http.Cookie{
+			Name:  "test-session-cookie",
+			Value: "another-yummy",
+			Path:  "/",
+		})
+		w.WriteHeader(http.StatusOK)
+		fmt.Fprintln(w, `{}`)
+	})
+
+	server := httptest.NewServer(mux)
+	t.Cleanup(server.Close)
+
+	jar, err := cookiejar.New(nil)
+	require.NoError(t, err)
+
+	u, err := url.Parse(server.URL)
+	require.NoError(t, err)
+	jar.SetCookies(u, []*http.Cookie{
+		{
+			Name:  "test-cookie",
+			Value: "yummy",
+			Path:  "/",
+		},
+	})
+
+	client, err := NewClient("", WithBaseURL(server.URL), WithHTTPClient(server.Client()), WithCookieJar(jar))
+	require.NoError(t, err)
+
+	_, resp, err := client.Users.CurrentUser()
+	require.NoError(t, err)
+
+	assert.Equal(t, http.StatusOK, resp.StatusCode)
+
+	cookiesInJar := client.HTTPClient().Jar.Cookies(u)
+	cookieMap := make(map[string]string, len(cookiesInJar))
+	for _, c := range cookiesInJar {
+		cookieMap[c.Name] = c.Value
+	}
+	assert.Equal(t, "another-yummy", cookieMap["test-session-cookie"])
+}
+
+func TestWithInterceptor(t *testing.T) {
+	t.Parallel()
+
+	t.Run("when nil interceptor has been passed, then it will result in an error", func(t *testing.T) {
+		_, err := NewClient("", WithInterceptor(nil))
+		require.Error(t, err)
+	})
+
+	t.Run("when interceptor option is provided, then it is used in the client as part of the http round tripping of the transportation", func(t *testing.T) {
+		client, err := NewClient("",
+			WithInterceptor(func(next http.RoundTripper) http.RoundTripper {
+				assert.NotNil(t, next, "it was expected that the next middleware is not empty, most likely being the default transport in worse case scenario")
+				return StubRoundTripper(func(r *http.Request) (*http.Response, error) {
+					return &http.Response{StatusCode: http.StatusOK, Body: io.NopCloser(strings.NewReader("{}"))}, nil
+				})
+			}),
+		)
+		require.NoError(t, err)
+
+		_, resp, err := client.Users.CurrentUser()
+		require.NoError(t, err)
+
+		assert.Equal(t, http.StatusOK, resp.StatusCode)
+	})
+
+	t.Run("enables request manipulation", func(t *testing.T) {
+		client, err := NewClient("",
+			WithInterceptor(func(next http.RoundTripper) http.RoundTripper {
+				assert.NotNil(t, next, "it was expected that the next middleware is not empty, most likely being the default transport in worse case scenario")
+				return StubRoundTripper(func(r *http.Request) (*http.Response, error) {
+					assert.Equal(t, "foo", r.Header.Get("X-Foo"))
+					respHeaders := http.Header{}
+					respHeaders.Set("X-Bar", "bar")
+					return &http.Response{
+						StatusCode: http.StatusOK,
+						Body:       io.NopCloser(strings.NewReader("{}")),
+						Header:     respHeaders,
+					}, nil
+				})
+			}),
+		)
+		require.NoError(t, err)
+
+		_, resp, err := client.Users.CurrentUser(func(r *retryablehttp.Request) error {
+			r.Request.Header.Set("X-Foo", "foo")
+			return nil
+		})
+		require.NoError(t, err)
+		assert.Equal(t, http.StatusOK, resp.StatusCode)
+		assert.Equal(t, "bar", resp.Header.Get("X-Bar"))
+	})
+
+	t.Run("ordering aligned to how interceptors are provided, as this makes it easier to read a option setup", func(t *testing.T) {
+		var ordering []int
+		client, err := NewClient("",
+			WithInterceptor(func(next http.RoundTripper) http.RoundTripper {
+				assert.NotNil(t, next)
+				return StubRoundTripper(func(r *http.Request) (*http.Response, error) {
+					ordering = append(ordering, 1)
+					return next.RoundTrip(r)
+				})
+			}),
+			WithInterceptor(func(next http.RoundTripper) http.RoundTripper {
+				assert.NotNil(t, next)
+				return StubRoundTripper(func(r *http.Request) (*http.Response, error) {
+					ordering = append(ordering, 2)
+					return next.RoundTrip(r)
+				})
+			}),
+			WithInterceptor(func(next http.RoundTripper) http.RoundTripper {
+				assert.NotNil(t, next)
+				return StubRoundTripper(func(r *http.Request) (*http.Response, error) {
+					ordering = append(ordering, 3)
+					return &http.Response{StatusCode: http.StatusOK, Body: io.NopCloser(strings.NewReader("{}"))}, nil
+				})
+			}),
+		)
+		require.NoError(t, err)
+
+		_, _, _ = client.Users.CurrentUser()
+		assert.Equal(t, []int{1, 2, 3}, ordering)
+	})
+
+	t.Run("e2e", func(t *testing.T) {
+		const endpoint = "/api/v4/user"
+
+		mux := http.NewServeMux()
+		mux.HandleFunc(endpoint, func(w http.ResponseWriter, r *http.Request) {
+			w.Header().Set("X-Foo", "bar")
+			w.WriteHeader(http.StatusOK)
+			fmt.Fprintln(w, `{}`)
+		})
+
+		server := httptest.NewServer(mux)
+		t.Cleanup(server.Close)
+
+		client, err := NewClient("",
+			WithBaseURL(server.URL),
+			WithHTTPClient(server.Client()),
+			WithInterceptor(func(next http.RoundTripper) http.RoundTripper {
+				return StubRoundTripper(func(r *http.Request) (*http.Response, error) {
+					assert.Contains(t, r.URL.Path, endpoint)
+					resp, err := next.RoundTrip(r)
+					if err == nil {
+						assert.Equal(t, "bar", resp.Header.Get("X-Foo"))
+					}
+					return resp, err
+				})
+			}))
+
+		require.NoError(t, err)
+
+		_, resp, err := client.Users.CurrentUser()
+		require.NoError(t, err)
+		assert.Equal(t, http.StatusOK, resp.StatusCode)
+	})
+}
+
+type StubRoundTripper func(r *http.Request) (*http.Response, error)
+
+func (fn StubRoundTripper) RoundTrip(r *http.Request) (*http.Response, error) {
+	return fn(r)
+}
