@@ -1,6 +1,7 @@
 package gitlab
 
 import (
+	"bytes"
 	"encoding/json"
 	"fmt"
 	"io"
@@ -10,6 +11,7 @@ import (
 	"testing"
 	"time"
 
+	"github.com/google/go-querystring/query"
 	"github.com/stretchr/testify/assert"
 )
 
@@ -43,8 +45,8 @@ func TestGetGroup(t *testing.T) {
 			testMethod(t, r, http.MethodGet)
 			fmt.Fprint(w, `
 			{
-			"id": 1, 
-			"name": "g", 
+			"id": 1,
+			"name": "g",
 			"default_branch": "branch",
 			"shared_with_groups": [
 				{
@@ -950,14 +952,14 @@ func TestUpdateGroupWithIPRestrictionRanges(t *testing.T) {
 				t.Fatalf("Failed to read the request body. Error: %v", err)
 			}
 
-			var bodyJson map[string]interface{}
-			err = json.Unmarshal(body, &bodyJson)
+			var bodyJSON map[string]any
+			err = json.Unmarshal(body, &bodyJSON)
 			if err != nil {
 				t.Fatalf("Failed to parse the request body into JSON. Error: %v", err)
 			}
 
-			if bodyJson["ip_restriction_ranges"] != ipRange {
-				t.Fatalf("Test failed. `ip_restriction_ranges` expected to be '%v', got %v", ipRange, bodyJson["ip_restriction_ranges"])
+			if bodyJSON["ip_restriction_ranges"] != ipRange {
+				t.Fatalf("Test failed. `ip_restriction_ranges` expected to be '%v', got %v", ipRange, bodyJSON["ip_restriction_ranges"])
 			}
 
 			fmt.Fprintf(w, `{"id": 1, "ip_restriction_ranges" : "%v"}`, ipRange)
@@ -984,7 +986,7 @@ func TestGetGroupWithEmailsEnabled(t *testing.T) {
 		func(w http.ResponseWriter, r *http.Request) {
 			testMethod(t, r, http.MethodGet)
 
-			// Modified from https://docs.gitlab.com/ee/api/groups.html#details-of-a-group
+			// Modified from https://docs.gitlab.com/api/groups/#details-of-a-group
 			fmt.Fprint(w, `
 			{
 				"id": 1,
@@ -1035,14 +1037,14 @@ func TestCreateGroupWithEmailsEnabled(t *testing.T) {
 			}
 
 			// unmarshal into generic JSON since we don't want to test CreateGroupOptions using itself to validate.
-			var bodyJson map[string]interface{}
-			err = json.Unmarshal(body, &bodyJson)
+			var bodyJSON map[string]any
+			err = json.Unmarshal(body, &bodyJSON)
 			if err != nil {
 				t.Fatalf("Failed to parse the request body into JSON. Error: %v", err)
 			}
 
-			if bodyJson["emails_enabled"] != true {
-				t.Fatalf("Test failed. `emails_enabled` expected to be true, got %v", bodyJson["emails_enabled"])
+			if bodyJSON["emails_enabled"] != true {
+				t.Fatalf("Test failed. `emails_enabled` expected to be true, got %v", bodyJSON["emails_enabled"])
 			}
 
 			// Response is tested via the "GET" test, only test the actual request here.
@@ -1070,14 +1072,14 @@ func TestUpdateGroupWithEmailsEnabled(t *testing.T) {
 			}
 
 			// unmarshal into generic JSON since we don't want to test UpdateGroupOptions using itself to validate.
-			var bodyJson map[string]interface{}
-			err = json.Unmarshal(body, &bodyJson)
+			var bodyJSON map[string]any
+			err = json.Unmarshal(body, &bodyJSON)
 			if err != nil {
 				t.Fatalf("Failed to parse the request body into JSON. Error: %v", err)
 			}
 
-			if bodyJson["emails_enabled"] != true {
-				t.Fatalf("Test failed. `emails_enabled` expected to be true, got %v", bodyJson["emails_enabled"])
+			if bodyJSON["emails_enabled"] != true {
+				t.Fatalf("Test failed. `emails_enabled` expected to be true, got %v", bodyJSON["emails_enabled"])
 			}
 
 			// Response is tested via the "GET" test, only test the actual request here.
@@ -1290,14 +1292,14 @@ func TestUpdateGroupWithAllowedEmailDomainsList(t *testing.T) {
 				t.Fatalf("Failed to read the request body. Error: %v", err)
 			}
 
-			var bodyJson map[string]interface{}
-			err = json.Unmarshal(body, &bodyJson)
+			var bodyJSON map[string]any
+			err = json.Unmarshal(body, &bodyJSON)
 			if err != nil {
 				t.Fatalf("Failed to parse the request body into JSON. Error: %v", err)
 			}
 
-			if bodyJson["allowed_email_domains_list"] != domain {
-				t.Fatalf("Test failed. `allowed_email_domains_list` expected to be '%v', got %v", domain, bodyJson["allowed_email_domains_list"])
+			if bodyJSON["allowed_email_domains_list"] != domain {
+				t.Fatalf("Test failed. `allowed_email_domains_list` expected to be '%v', got %v", domain, bodyJSON["allowed_email_domains_list"])
 			}
 
 			fmt.Fprintf(w, `{"id": 1, "allowed_email_domains_list" : "%v"}`, domain)
@@ -1315,3 +1317,230 @@ func TestUpdateGroupWithAllowedEmailDomainsList(t *testing.T) {
 		t.Errorf("Groups.UpdatedGroup returned %+v, want %+v", group, want)
 	}
 }
+
+func TestCreateGroupDefaultBranchSettingsWithAvatar(t *testing.T) {
+	t.Parallel()
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/groups",
+		func(w http.ResponseWriter, r *http.Request) {
+			testMethod(t, r, http.MethodPost)
+
+			testFormBody(t, r, "name", "g")
+			testFormBody(t, r, "path", "g")
+			testFormBody(t, r, "default_branch_protection_defaults[allowed_to_push][][access_level]", "40")
+			testFormBody(t, r, "default_branch_protection_defaults[allowed_to_merge][][access_level]", "40")
+
+			fmt.Fprint(w, `
+			{
+				"id": 1,
+				"name": "g",
+				"path": "g",
+				"default_branch_protection_defaults": {
+					"allowed_to_push": [
+						{
+							"access_level": 40
+						}
+					],
+					"allow_force_push": false,
+					"allowed_to_merge": [
+						{
+							"access_level": 40
+						}
+					]
+				},
+				"avatar_url":"http://localhost/uploads/-/system/group/avatar/999/avatar.png"
+			}
+			`)
+		})
+
+	avatar := new(bytes.Buffer)
+	groupAvatar := &GroupAvatar{
+		Image:    avatar,
+		Filename: "avatar.png",
+	}
+	opt := &CreateGroupOptions{
+		Name:   Ptr("g"),
+		Path:   Ptr("g"),
+		Avatar: groupAvatar,
+		DefaultBranchProtectionDefaults: &DefaultBranchProtectionDefaultsOptions{
+			AllowedToPush: &[]*GroupAccessLevel{
+				{
+					AccessLevel: Ptr(AccessLevelValue(40)),
+				},
+			},
+			AllowedToMerge: &[]*GroupAccessLevel{
+				{
+					AccessLevel: Ptr(AccessLevelValue(40)),
+				},
+			},
+		},
+	}
+
+	var _ query.Encoder = &DefaultBranchProtectionDefaultsOptions{}
+
+	group, _, err := client.Groups.CreateGroup(opt, nil)
+	if err != nil {
+		t.Errorf("Groups.CreateGroup returned error: %v", err)
+	}
+
+	// Create the group that we want to get back
+	want := &Group{
+		ID:        1,
+		Name:      "g",
+		Path:      "g",
+		AvatarURL: "http://localhost/uploads/-/system/group/avatar/999/avatar.png",
+		DefaultBranchProtectionDefaults: &BranchProtectionDefaults{
+			AllowedToMerge: []*GroupAccessLevel{
+				{
+					AccessLevel: Ptr(MaintainerPermissions),
+				},
+			},
+			AllowedToPush: []*GroupAccessLevel{
+				{
+					AccessLevel: Ptr(MaintainerPermissions),
+				},
+			},
+		},
+	}
+
+	if !reflect.DeepEqual(want, group) {
+		t.Errorf("Groups.CreateGroup returned %+v, want %+v", group, want)
+	}
+}
+
+// Test to ensure an error occurs when providing an avatar and multiple
+// allowed to push / allowed to merge access levels during group creation
+func TestCreateGroupMultipleDefaultBranchSettingsWithAvatarShouldError(t *testing.T) {
+	t.Parallel()
+	_, client := setup(t)
+
+	avatar := new(bytes.Buffer)
+	groupAvatar := &GroupAvatar{
+		Image:    avatar,
+		Filename: "avatar.png",
+	}
+	opt := &CreateGroupOptions{
+		Name:   Ptr("g"),
+		Path:   Ptr("g"),
+		Avatar: groupAvatar,
+		DefaultBranchProtectionDefaults: &DefaultBranchProtectionDefaultsOptions{
+			AllowedToPush: &[]*GroupAccessLevel{
+				{
+					AccessLevel: Ptr(AccessLevelValue(40)),
+				},
+				{
+					AccessLevel: Ptr(AccessLevelValue(30)),
+				},
+			},
+			AllowedToMerge: &[]*GroupAccessLevel{
+				{
+					AccessLevel: Ptr(AccessLevelValue(40)),
+				},
+				{
+					AccessLevel: Ptr(AccessLevelValue(30)),
+				},
+			},
+		},
+	}
+
+	var _ query.Encoder = &DefaultBranchProtectionDefaultsOptions{}
+
+	group, _, err := client.Groups.CreateGroup(opt, nil)
+	assert.Error(t, err)
+	assert.Equal(t, "multiple access levels for allowed_to_merge or allowed_to_push are not permitted when an Avatar is also specified as it will result in unexpected behavior", err.Error())
+	assert.Nil(t, group)
+}
+
+// Test to ensure an error occurs when providing an avatar and multiple
+// allowed to push / allowed to merge access levels during group update
+func TestUpdateGroupMultipleDefaultBranchSettingsWithAvatarShouldError(t *testing.T) {
+	t.Parallel()
+	_, client := setup(t)
+
+	avatar := new(bytes.Buffer)
+	groupAvatar := &GroupAvatar{
+		Image:    avatar,
+		Filename: "avatar.png",
+	}
+	opt := &UpdateGroupOptions{
+		Name:   Ptr("g"),
+		Path:   Ptr("g"),
+		Avatar: groupAvatar,
+		DefaultBranchProtectionDefaults: &DefaultBranchProtectionDefaultsOptions{
+			AllowedToPush: &[]*GroupAccessLevel{
+				{
+					AccessLevel: Ptr(AccessLevelValue(40)),
+				},
+				{
+					AccessLevel: Ptr(AccessLevelValue(30)),
+				},
+			},
+			AllowedToMerge: &[]*GroupAccessLevel{
+				{
+					AccessLevel: Ptr(AccessLevelValue(40)),
+				},
+				{
+					AccessLevel: Ptr(AccessLevelValue(30)),
+				},
+			},
+		},
+	}
+
+	var _ query.Encoder = &DefaultBranchProtectionDefaultsOptions{}
+
+	group, _, err := client.Groups.UpdateGroup(1, opt)
+	assert.Error(t, err)
+	assert.Equal(t, "multiple access levels for allowed_to_merge or allowed_to_push are not permitted when an Avatar is also specified as it will result in unexpected behavior", err.Error())
+	assert.Nil(t, group)
+}
+
+func TestCreateGroupWithAvatar(t *testing.T) {
+	t.Parallel()
+	mux, client := setup(t)
+
+	mux.HandleFunc("/api/v4/groups",
+		func(w http.ResponseWriter, r *http.Request) {
+			testMethod(t, r, http.MethodPost)
+
+			testFormBody(t, r, "name", "g")
+			testFormBody(t, r, "path", "g")
+
+			fmt.Fprint(w, `
+			{
+				"id": 1,
+				"name": "g",
+				"path": "g",
+				"avatar_url":"http://localhost/uploads/-/system/group/avatar/999/avatar.png"
+			}
+			`)
+		})
+
+	avatar := new(bytes.Buffer)
+	groupAvatar := &GroupAvatar{
+		Image:    avatar,
+		Filename: "avatar.png",
+	}
+	opt := &CreateGroupOptions{
+		Name:   Ptr("g"),
+		Path:   Ptr("g"),
+		Avatar: groupAvatar,
+	}
+
+	group, _, err := client.Groups.CreateGroup(opt, nil)
+	if err != nil {
+		t.Errorf("Groups.CreateGroup returned error: %v", err)
+	}
+
+	// Create the group that we want to get back
+	want := &Group{
+		ID:        1,
+		Name:      "g",
+		Path:      "g",
+		AvatarURL: "http://localhost/uploads/-/system/group/avatar/999/avatar.png",
+	}
+
+	if !reflect.DeepEqual(want, group) {
+		t.Errorf("Groups.CreateGroup returned %+v, want %+v", group, want)
+	}
+}
