@@ -63,7 +63,7 @@ func TestTagsService_ListTags(t *testing.T) {
 			Protected: true,
 		},
 	}
-	assert.Equal(t, tags, want)
+	assert.Equal(t, want, tags)
 }
 
 func TestTagsService_GetTag(t *testing.T) {
@@ -104,7 +104,7 @@ func TestTagsService_GetTag(t *testing.T) {
 	assert.NoError(t, err)
 	assert.NotNil(t, resp)
 
-	date := time.Date(2015, 2, 1, 21, 56, 31, 0, time.UTC)
+	date := time.Date(2015, time.February, 1, 21, 56, 31, 0, time.UTC)
 
 	want := &Tag{
 		Name:   "v5.0.0",
@@ -125,9 +125,10 @@ func TestTagsService_GetTag(t *testing.T) {
 		},
 		Release:   nil,
 		Protected: false,
+		CreatedAt: &date,
 	}
 
-	assert.Equal(t, tag, want)
+	assert.Equal(t, want, tag)
 }
 
 func TestTagsService_CreateTag(t *testing.T) {
@@ -171,7 +172,7 @@ func TestTagsService_CreateTag(t *testing.T) {
 	assert.NoError(t, err)
 	assert.NotNil(t, resp)
 
-	date := time.Date(2015, 2, 1, 21, 56, 31, 0, time.UTC)
+	date := time.Date(2015, time.February, 1, 21, 56, 31, 0, time.UTC)
 
 	want := &Tag{
 		Name:   "v1.0.0",
@@ -194,7 +195,7 @@ func TestTagsService_CreateTag(t *testing.T) {
 		Protected: false,
 	}
 
-	assert.Equal(t, tag, want)
+	assert.Equal(t, want, tag)
 }
 
 func TestTagsService_DeleteTag(t *testing.T) {
@@ -261,5 +262,5 @@ func TestTagsService_GetTagSignature(t *testing.T) {
 		},
 	}
 
-	assert.Equal(t, signature, want)
+	assert.Equal(t, want, signature)
 }
