@@ -432,10 +432,11 @@ func (c *compiler) resolveSubstitution(vars *Map, node Node, substitution *d2ast
 }
 
 func (c *compiler) overlay(base *Map, f *Field) {
-	if f.Map() == nil || f.Primary() != nil {
+	if f.Map() == nil {
 		c.errorf(f.References[0].Context_.Key, "invalid %s", NodeBoardKind(f))
 		return
 	}
+
 	base = base.CopyBase(f)
 	// Certain fields should never carry forward.
 	// If you give your scenario a label, you don't want all steps in a scenario to be labeled the same.
@@ -484,7 +485,7 @@ func (c *compiler) ampersandFilterMap(dst *Map, ast, scopeAST *d2ast.Map) bool {
 					return false
 				}
 				var ks string
-				if gctx.refctx.Key.HasMultiGlob() {
+				if gctx.refctx.Key.HasTripleGlob() {
 					ks = d2format.Format(d2ast.MakeKeyPathString(IDA(dst)))
 				} else {
 					ks = d2format.Format(d2ast.MakeKeyPathString(BoardIDA(dst)))
@@ -516,7 +517,7 @@ func (c *compiler) compileMap(dst *Map, ast, scopeAST *d2ast.Map) {
 			for _, g := range previousGlobs {
 				gctx2 := g.copy()
 				gctx2.refctx.ScopeMap = dst
-				if !g.refctx.Key.HasMultiGlob() {
+				if !g.refctx.Key.HasTripleGlob() {
 					// Triple globs already apply independently to each board
 					gctx2.copyApplied(g)
 				}
@@ -528,7 +529,7 @@ func (c *compiler) compileMap(dst *Map, ast, scopeAST *d2ast.Map) {
 				// We don't want globs applied in a given scenario to affect future boards
 				// Copying the applied fields and edges keeps the applications scoped to this board
 				// Note that this is different from steps, where applications carry over
-				if !g.refctx.Key.HasMultiGlob() {
+				if !g.refctx.Key.HasTripleGlob() {
 					// Triple globs already apply independently to each board
 					g2.copyApplied(g)
 				}
@@ -939,10 +940,13 @@ func (c *compiler) ampersandFilter(refctx *RefContext) bool {
 
 			return dstPath == filterValue
 		default:
-			f := refctx.ScopeMap.Parent().(*Field)
-			propName := refctx.Key.Key.Last().ScalarString()
-			value := refctx.Key.Value.ScalarBox().Unbox().ScalarString()
-			return c._ampersandPropertyFilter(propName, value, f, refctx.Key)
+			parent := refctx.ScopeMap.Parent()
+			if field, ok := parent.(*Field); ok {
+				propName := refctx.Key.Key.Last().ScalarString()
+				value := refctx.Key.Value.ScalarBox().Unbox().ScalarString()
+				return c._ampersandPropertyFilter(propName, value, field, refctx.Key)
+			}
+			return false
 		}
 	}
 	for _, f := range fa {
