@@ -859,7 +859,7 @@ func (m *Map) ensureField(i int, kp *d2ast.KeyPath, refctx *RefContext, create b
 	filter := func(f *Field, passthrough bool) bool {
 		if gctx != nil {
 			var ks string
-			if refctx.Key.HasMultiGlob() {
+			if refctx.Key.HasTripleGlob() {
 				ks = d2format.Format(d2ast.MakeKeyPathString(IDA(f)))
 			} else {
 				ks = d2format.Format(d2ast.MakeKeyPathString(BoardIDA(f)))
@@ -1021,7 +1021,7 @@ func (m *Map) ensureField(i int, kp *d2ast.KeyPath, refctx *RefContext, create b
 		}
 		for _, grefctx := range c.globRefContextStack {
 			var ks string
-			if grefctx.Key.HasMultiGlob() {
+			if grefctx.Key.HasTripleGlob() {
 				ks = d2format.Format(d2ast.MakeKeyPathString(IDA(f)))
 			} else {
 				ks = d2format.Format(d2ast.MakeKeyPathString(BoardIDA(f)))
@@ -1234,7 +1234,7 @@ func (m *Map) getEdges(eid *EdgeID, refctx *RefContext, gctx *globContext, ea *[
 			for _, e := range ea2 {
 				if gctx != nil {
 					var ks string
-					if refctx.Key.HasMultiGlob() {
+					if refctx.Key.HasTripleGlob() {
 						ks = d2format.Format(d2ast.MakeKeyPathString(IDA(e)))
 					} else {
 						ks = d2format.Format(d2ast.MakeKeyPathString(BoardIDA(e)))
@@ -1452,7 +1452,7 @@ func (m *Map) createEdge2(eid *EdgeID, refctx *RefContext, gctx *globContext, c
 		e2 := e.Copy(e.Parent()).(*Edge)
 		e2.ID = e2.ID.Copy()
 		e2.ID.Index = nil
-		if refctx.Key.HasMultiGlob() {
+		if refctx.Key.HasTripleGlob() {
 			ks = d2format.Format(d2ast.MakeKeyPathString(IDA(e2)))
 		} else {
 			ks = d2format.Format(d2ast.MakeKeyPathString(BoardIDA(e2)))
